@@ -296,7 +296,7 @@ gint get_move_pos(TEXTWND *ptw,gint x,gint y,gboolean move)
 		length=type[datapos-1];
 		datapos-=length;
 		ctype=get_char_type(p->text+datapos,length);
-		while (datapos>0 && (datapos-=length=type[datapos-1])>0) {
+		while (datapos>0 && (datapos-=length=type[datapos-1])>=0) {
 			ct=get_char_type(p->text+datapos,length);
 			if ((ctype&ct)==0) {
 				if (ctype!=0) {
