@@ -99,9 +99,7 @@ gboolean find_dialog(FIND *fd)
 	button0=gtk_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
 																_("(_F)"));
-	gtk_widget_add_accelerator(button0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	button1=gtk_button_new_with_label(_(""));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",find_dialog_clicked,fd);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
@@ -112,9 +110,7 @@ gboolean find_dialog(FIND *fd)
 	check=gtk_check_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
 											_("ʸ/ʸ̤(_C)"));
-	gtk_widget_add_accelerator(check,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),fd->ignorecase);
 	/* ܥܥå */
 	for (i=0;i<find_num;i++)
@@ -134,13 +130,9 @@ gboolean find_dialog(FIND *fd)
 	radio1=gtk_radio_button_new_with_label_from_widget(
 												GTK_RADIO_BUTTON(radio0),NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_U)"));
-	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_D)"));
-	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fd->arrow?radio1:radio0),
 																		TRUE);
 	/* ե졼ȥܥå */
@@ -157,7 +149,7 @@ gboolean find_dialog(FIND *fd)
 	gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame0),vbox);
 	frame1=gtk_frame_new(_(""));
-	vbox=gtk_vbox_new(FALSE,7);
+	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),radio1,FALSE,FALSE,0);
