@@ -147,14 +147,13 @@ gboolean jump_dialog(JMPDLG *jmp)
 	gtk_signal_connect(GTK_OBJECT(entry),"changed",jump_dialog_changed,jmp);
 	gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
 	/* ե졼ȥܥå */
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),entry,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),entry,TRUE,TRUE,0);
+	hbox=gtk_hbox_new(FALSE,7);
+	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
 	/* ɽ */
