@@ -31,7 +31,7 @@ static gchar *fontname;
 static gint ft_id;
 static GdkColor gdk_color[12];
 static GtkWidget *dialog;
-static GtkWidget *button0,*button3,*scroll;
+static GtkWidget *button0,*button3;
 static GtkWidget *check0,*check1,*check2,*check3,*check4,*check5;
 static GtkWidget *check6,*check7,*check8,*check9,*check10,*check11;
 static GtkWidget *clist,*entry0,*entry1,*label,*spin0,*spin1;
@@ -298,7 +298,7 @@ gboolean property_dialog(FTYPE *ft)
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
 	GtkAccelGroup *accel;
-	GtkWidget *button1,*button2,*button4;
+	GtkWidget *button1,*button2,*button4,*scroll;
 	GtkWidget *hbox,*tbox,*vbox;
 	GtkWidget *frame0,*frame1,*frame2,*frame3,*frame4;
 
@@ -321,20 +321,15 @@ gboolean property_dialog(FTYPE *ft)
 	button4=gtk_button_new_with_label(_(""));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
 																_("ѹ(_P)"));
-	gtk_widget_add_accelerator(button0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
 															_("ե(_F)"));
-	gtk_widget_add_accelerator(button1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	if (button2!=NULL) {
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),
 													_("ե륿(_A)"));
 		gtk_widget_add_accelerator(button2,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+															GDK_MOD1_MASK,0);
 	}
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 										property_dialog_clicked_color,NULL);
@@ -347,6 +342,11 @@ gboolean property_dialog(FTYPE *ft)
 										property_dialog_clicked_ok,ft);
 	gtk_signal_connect_object(GTK_OBJECT(button4),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
+	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
+	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
+	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
+	GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
+	GTK_WIDGET_SET_FLAGS(button4,GTK_CAN_DEFAULT);
 	/* åܥ */
 	check0=gtk_check_button_new_with_label(NULL);
 	check1=gtk_check_button_new_with_label(NULL);
@@ -361,57 +361,35 @@ gboolean property_dialog(FTYPE *ft)
 	check10=gtk_check_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
 															_("å(_G)"));
-	gtk_widget_add_accelerator(check0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check1)->child),
 														_("ѥڡ(_S)"));
-	gtk_widget_add_accelerator(check1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check2)->child),
 														_("ԥ(_E)"));
-	gtk_widget_add_accelerator(check2,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check2,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check3)->child),
 													_("ޡɽ(_M)"));
-	gtk_widget_add_accelerator(check3,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check3,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check4)->child),
 															_("ޤ֤(_I)"));
-	gtk_widget_add_accelerator(check4,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check4,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check5)->child),
 														_("ʸ(_C)"));
-	gtk_widget_add_accelerator(check5,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check5,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check6)->child),_("(_U)"));
-	gtk_widget_add_accelerator(check6,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check6,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check7)->child),_("(_V)"));
-	gtk_widget_add_accelerator(check7,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check7,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check8)->child),
 									_("եκǸ^Z(1A)դ(_Z)"));
-	gtk_widget_add_accelerator(check8,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check8,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check9)->child),
 												_("¸ǧ(_O)"));
-	gtk_widget_add_accelerator(check9,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check9,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check10)->child),
 													_("ƥ࿧Ȥ(_Y)"));
-	gtk_widget_add_accelerator(check10,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check10,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->gline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),ft->space);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),ft->crlf);
@@ -449,9 +427,7 @@ gboolean property_dialog(FTYPE *ft)
 		check11=gtk_check_button_new_with_label(NULL);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check11)->child),
 										_("ե륿פϢŤ(_A)"));
-		gtk_widget_add_accelerator(check11,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+		gtk_widget_add_accelerator(check11,"clicked",accel,key,GDK_MOD1_MASK,0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check11),ft->associate);
 		gtk_signal_connect(GTK_OBJECT(check11),"toggled",
 											property_dialog_ok_sensitive,NULL);
