@@ -836,8 +836,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 			top=ptw->top;
 			sx=MAX(ptw->drawing->allocation.width/ptw->fontwidth,1);
 			sy=MAX(ptw->drawing->allocation.height/ptw->fontheight,1);
-			alt=(event->state&(GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK))!=0;
+			alt=(event->state&GDK_MOD1_MASK)!=0;
 			ctrl=(event->state&GDK_CONTROL_MASK)!=0;
 			switch (event->keyval) {
 			case GDK_Home:
@@ -1037,6 +1036,9 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 		result=TRUE;
 		break;
 	case GDK_Return:
+	case GDK_KP_Enter:
+	case GDK_ISO_Enter:
+	case GDK_3270_Enter:
 		{
 			DOING *d;
 			GdkPoint select;
@@ -1189,8 +1191,7 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 		loop:
 		if (event->string!=NULL
 				&& ((guchar)event->string[0]>=' ' || event->string[0]=='\t')
-				&& (event->state&(GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-										|GDK_MOD4_MASK|GDK_MOD5_MASK))==0) {
+										&& (event->state&GDK_MOD1_MASK)==0) {
 			DOING *d;
 			GdkPoint select;
 
